@@ -16,17 +16,17 @@ class PROXIES:
                 code = rsp.status_code
                 r = rsp.text.strip()
                 if "白名单" in r:
-                    print('请先设置白名单')
-                    return None
+                    return {"code":400,"message":r,"proxies":""}
                 elif code == 200:
                     proxies = {"https": "http://" + r,
                                "http": "http://" + r}
-                    return proxies
+                    return {"code":200,"message":"success","proxies":proxies}
                 else:
-                    print('Error...')
+                    return {"code":401,"message":r,"proxies":""}
             except:
-                print('failed to Obtain ip,'
-                      'try again')
+                return {"code": 500,
+                        "message": 'failed to Obtain ip,try again',
+                        "proxies": ""}
 
     @classmethod
     def get_aby_proxies(cls):
